package test.roaster;

import java.io.Serializable;

import org.jboss.forge.roaster.Roaster;
import org.jboss.forge.roaster.model.source.JavaClassSource;
import org.junit.jupiter.api.Test;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.FrameworkUtil;

class TestJavaParser {

	private String toState(int state) {
		switch (state) {
		case Bundle.UNINSTALLED:
			return "UNINSTALLED";
		case Bundle.INSTALLED:
			return "INSTALLED";
		case Bundle.RESOLVED:
			return "RESOLVED";
		case Bundle.STARTING:
			return "STARTING";
		case Bundle.STOPPING:
			return "STOPPING";
		case Bundle.ACTIVE:
			return "ACTIVE";
		default:
			return null;
		}
	}

	@Test
	void test() {
		Bundle bundle = FrameworkUtil.getBundle(getClass());
		BundleContext ctx = bundle.getBundleContext();
		for (Bundle b : ctx.getBundles()) {
			System.out.println(b.getSymbolicName() + ' ' + toState(b.getState()));
		}
		final JavaClassSource javaClass = Roaster.create(JavaClassSource.class);
		javaClass.setPackage("com.company.example").setName("Person");

		javaClass.addInterface(Serializable.class);
		javaClass.addField()
		  .setName("serialVersionUID")
		  .setType("long")
		  .setLiteralInitializer("1L")
		  .setPrivate()
		  .setStatic(true)
		  .setFinal(true);

		javaClass.addProperty(Integer.class, "id").setMutable(false);
		javaClass.addProperty(String.class, "firstName");
		javaClass.addProperty("String", "lastName");

		javaClass.addMethod()
		  .setConstructor(true)
		  .setPublic()
		  .setBody("this.id = id;")
		  .addParameter(Integer.class, "id");		
		
		System.out.println("Test Roaster");		
	}

}
